%define pg_version 6.5.3
%define pg_release C1
%define pg_access_version 0.98
%define pg_jdbc_version 6.5-1.1
%define pgdata /home/pgsql
%define pgport 5583

Summary: The Postgres SQL database package.
Name: postgresql
Version: %{pg_version}
Release: %{pg_release}
Copyright: BSD
Group: Applications/Databases
Source0: ftp://ftp.postgresql.org/pub/postgresql-%{pg_version}.tar.gz
Source1: ftp://www.flex.ro/pub/pgaccess/pgaccess-%{pg_access_version}.tar.gz
Source2: http://www.retep.org.uk/postgres/jdbc%{pg_jdbc_version}.jar
Source3: postgresql.init
Source4: man.tar.gz
Buildroot: /var/tmp/pgsql-root
Prefix: /usr
Prereq: /sbin/chkconfig /sbin/ldconfig /usr/sbin/useradd
Vendor: The PostgreSQL Global Development Group
Packager: Duncan Laurie <duncan@cobalt.com>
Url: http://www.postgresql.org/
ExcludeArch: armv4l

%description
PostgreSQL is an advanced Object-Relational database management system
(DBMS) that supports almost all SQL constructs (including transactions,
subselects and user-defined types and functions).
postgresql includes the client programs and client libraries
that you'll need to access a PostgreSQL database management system
server.  This package contains the client libraries for C, and C++,
as well as command-line utilities for managing PostgreSQL databases on a
remote server. If you just want to connect to an existing remote
PostgreSQL server, this package is all you need.

You should install postgresql if you're installing postgresql-server.

%package server
Summary: The programs needed for a PostgreSQL server.
Group: Applications/Databases
Requires: postgresql = %{pg_version}

%description server
postgresql-server includes the programs needed to create and run a PostgreSQL
server, which will in turn allow you to create and maintain PostgreSQL
databases.  PostgreSQL is an advanced Object-Relational database
management system (DBMS) that supports almost all SQL constructs
(including transactions, subselects and user-defined types and
functions).

You should install postgresql if you want to create and maintain your
own PostgreSQL databases and/or your own PostgreSQL server.

%package devel
Summary: PostgreSQL development header files and libraries.
Group: Development/Libraries

%description devel
This package contains the header files and libraries needed to
compile C or C++ applications which will directly interact with
a PostgreSQL server. It include the ecpg Embedded C Postgres
preprocessor.

Install this package if you want to develop applications which will
interact with a PostgreSQL server.

%package jdbc
Summary: The java-based client programs needed for accessing a PostgreSQL server.
Group: Applications/Databases

%description jdbc
postgresql-jdbc includes the jar file that you'll need to access a PostgreSQL
database management system server.

%package odbc
Summary: The ODBC driver needed for accessing a PostgreSQL server.
Group: Applications/Databases

%description odbc
Postgresql-odbc includes the odbc driver and sample configuration files
that you'll need to access a PostgreSQL database management system
server.

%package perl
Summary: The perl-based client programs needed for accessing a PostgreSQL server.
Group: Applications/Databases
Requires: perl >= 5.004-4

%description perl
postgresql-perl includes the perl-based client programs and client libraries
that you'll need to access a PostgreSQL database management system
server.

%package python
Summary: The python-based client programs needed for accessing a PostgreSQL server.
Group: Applications/Databases
Requires: python >= 1.5

%description python
postgresql-python includes the python-based client programs and client libraries
that you'll need to access a PostgreSQL database management system
server.

%package tcl
Summary: The tcl-based client programs needed for accessing a PostgreSQL server.
Group: Applications/Databases
Requires: tcl >= 8.0, tk >= 8.0

%description tcl
postgresql-tcl includes the tcl-based client programs and client libraries
that you'll need to access a PostgreSQL database management system
server.  This package contains the tcl client libraries,
as well as pgaccess, a wish-based utility for manipulating PostgreSQL databases.

%package pgaccess
Summary: A client for interactively querying the postgres server
Group: Applications/Databases
Requires: tcl >= 8.0, tk >= 8.0

%description pgaccess
pgaccess is a client for interactive use of postgres

%package doc
Summary: the documentation for PostgreSQL
Group: Applications/Databases

%description doc
postgresql-doc contains the manuals/docs for the database

%prep
%setup -n postgresql-%{pg_version}

cd src/bin
gzip -dc $RPM_SOURCE_DIR/pgaccess-%{pg_access_version}.tar.gz | tar -xvvf -

%build
pushd src
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr \
	--enable-hba --with-pgport=%{pgport} \
        --enable-locale --with-mb=EUC_JP \
	--with-perl --with-tcl --with-tk --with-x \
	--with-odbc --with-java \
	--with-python
make all
pushd interfaces/python
cp /usr/lib/python1.5/config/Makefile.pre.in .
echo *shared* > Setup
echo _pg pgmodule.c -I../../include -I../libpq -L../libpq -lpq -lcrypt >> Setup
make -f Makefile.pre.in boot
make
popd
popd

# Unpack the docs
make all PGDOCS=unpacked -C doc

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/{include/pgsql,lib,bin,man}
mkdir -p $RPM_BUILD_ROOT/%{pgdata}
#mkdir -p $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/%{buildarch}-linux/auto/Pg

make POSTGRESDIR=$RPM_BUILD_ROOT/usr PREFIX=$RPM_BUILD_ROOT/usr -C src install
make POSTGRESDIR=$RPM_BUILD_ROOT/usr PREFIX=$RPM_BUILD_ROOT/usr -C src/bin/pgaccess install
make POSTGRESDIR=$RPM_BUILD_ROOT/usr PREFIX=$RPM_BUILD_ROOT/usr -C src/interfaces/perl5 install

# Get rid of the packing list generated by the perl Makefile, and build my own...
find $RPM_BUILD_ROOT/usr/lib/perl5 -name .packlist -exec rm -f {} \;
find $RPM_BUILD_ROOT/usr/lib/perl5 -type f -print | \
	sed -e "s|$RPM_BUILD_ROOT/|/|g" > perlfiles.list
find $RPM_BUILD_ROOT/usr/lib/perl5 -type d -name Pg -print | \
	sed -e "s|$RPM_BUILD_ROOT/|%dir /|g" >> perlfiles.list

pushd $RPM_BUILD_ROOT/usr/man
gzip -dc $RPM_SOURCE_DIR/man.tar.gz | tar -xf -
popd

# Move all includes beneath /usr/include/pgsql.
pushd $RPM_BUILD_ROOT/usr/include
rm -rf include
for f in *.h access commands executor lib libpq libpq++.H libpq++ port utils ; do
    mv $f pgsql
done
popd

# Move all templates/examples beneath /usr/lib/pgsql
pushd $RPM_BUILD_ROOT/usr/lib
mkdir -p pgsql
mv *source *sample pgsql
popd

# ODBC
pushd src/interfaces/odbc
cp odbcinst.ini $RPM_BUILD_ROOT/%{pgdata}
popd

# Perl
# No need to do anything right now. But later, we will try building everything
# on the target machine to use the architecture-specific installation features
# in the perl installation.
#pushd src/interfaces/perl5
#mkdir -p $RPM_BUILD_ROOT/usr/lib/pgsql/perl5
#cp Pg.pm $RPM_BUILD_ROOT/usr/lib/pgsql/perl5
#pushd blib/arch/auto/Pg
#cp Pg.so Pg.bs $RPM_BUILD_ROOT/usr/lib/pgsql/perl5
#popd
#popd

# Python
pushd src/interfaces/python
# Makefile.pre.in doesn't yet support .py files anyway, so we stick to a manual installation
mkdir -p $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages
install -m 644 _pgmodule.so *.py $RPM_BUILD_ROOT/usr/lib/python1.5/site-packages/
popd

# Java/JDBC
# We know that JDK1.2 is pre-beta at this time, so just install the JDK1.1-compatible driver.
# The user will have to set a CLASSPATH to find it here, but not sure where else to put it...
install -m 755 $RPM_SOURCE_DIR/jdbc%{pg_jdbc_version}.jar $RPM_BUILD_ROOT/usr/lib/pgsql

chmod 644 $RPM_BUILD_ROOT/usr/man/*/*
chmod 755 $RPM_BUILD_ROOT/usr/lib/*

#install -d $RPM_BUILD_ROOT/etc/rc.d/init.d
#install -m 755 $RPM_SOURCE_DIR/postgresql.init $RPM_BUILD_ROOT/etc/rc.d/init.d/postgresql
#for I in 3 5; do
#	install -d $RPM_BUILD_ROOT/etc/rc.d/rc$I.d
#	pushd $RPM_BUILD_ROOT/etc/rc.d/rc$I.d
#	ln -s ../init.d/postgresql S73postgresql
#	popd
#done

## Create sample database
## Disabled because an in-place upgrade using rpm only is probably not the right thing to do.
## Also, it is a PITA; should let the user decide how to coordinate dump and reload if necessary.
#PATH=/usr/sbin:$PATH useradd -M -r -d %{pgdata} -s /bin/bash \
#	-c "PostgreSQL Server" postgres || :

# stop running servers
killall postmaster &> /dev/null || :

useradd -M -o -r -d /home/pgsql -s /bin/bash \
	-c "PostgreSQL Server" postgres >/dev/null 2>&1 || :
chown -R postgres.postgres $RPM_BUILD_ROOT/%{pgdata} &> /dev/null || :

export PATH=$PATH:$RPM_BUILD_ROOT/usr/bin
[ ! -f $RPM_BUILD_ROOT/usr/lib/libpq.so.1 ] && ln -sf libpq.so $RPM_BUILD_ROOT/usr/lib/libpq.so.1
unset ENV || :

# init the database
su postgres -c "LD_LIBRARY_PATH=$RPM_BUILD_ROOT/usr/lib \
  $RPM_BUILD_ROOT/usr/bin/initdb -e EUC_JP --pgdata=$RPM_BUILD_ROOT/%{pgdata} \
  --pglib=$RPM_BUILD_ROOT/usr/lib/pgsql" &> /dev/null || :

# start the postmaster
su -l postgres -c "$RPM_BUILD_ROOT/usr/bin/postmaster -S -D$RPM_BUILD_ROOT/%{pgdata}" &> /dev/null || :

# create the cobalt database
su postgres -c "LD_LIBRARY_PATH=$RPM_BUILD_ROOT/usr/lib \
  $RPM_BUILD_ROOT/usr/bin/createdb cobalt" &> /dev/null || :

# add the admin user
su postgres -c "LD_LIBRARY_PATH=$RPM_BUILD_ROOT/usr/lib \
  $RPM_BUILD_ROOT/usr/bin/createuser -D -U -i 110 admin" < /bin/echo "n\n" &> /dev/null || :

[ -L $RPM_BUILD_ROOT/usr/lib/libpq.so.1 ] && rm -f $RPM_BUILD_ROOT/usr/lib/libpq.so.1

# stop the postmaster
killall postmaster &> /dev/null || :

## this was a good one
#chmod 640 $RPM_BUILD_ROOT/%{pgdata}/pg_pwd
#mkdir -p howto
#tar xzf $RPM_SOURCE_DIR/pgsql-Database-HOWTO-html.tar.gz -C howto

# Strip 'em all
for FILE in ecpg pg_dump pg_encoding pg_id pg_passwd pg_version pgtclsh pgtksh \
            postgres postmaster psql; do
	strip $RPM_BUILD_ROOT/usr/bin/$FILE &> /dev/null || :
done


%pre server
useradd -M -o -r -d /home/pgsql -s /bin/bash \
	-c "PostgreSQL Server" postgres &>/dev/null || :

%post -p /sbin/ldconfig

%post -p /sbin/ldconfig server

%post perl
# We *should* use the architecture-specific area to hold our perl interface.
# For now, we will use the architecture-neutral areas, and prebuild everything.
#PerlTarget=`perl -MConfig -e 'print $Config{archlib}'`
#pushd /usr/lib/pgsql/perl5
#mv Pg.pm $PerlTarget/
#mv Pg.so Pg.bs $PerlTarget/auto/Pg/
#popd

%post -p /sbin/ldconfig odbc

%post -p /sbin/ldconfig tcl

%preun
if [ $1 = 0 ] ; then
	chkconfig --del postgresql
fi

%postun -p /sbin/ldconfig

%postun server

/sbin/ldconfig
if [ $1 = 0 ] ; then
	userdel postgres >/dev/null 2>&1 || : 
fi

%postun -p /sbin/ldconfig odbc

%postun -p /sbin/ldconfig tcl

%clean
rm -rf $RPM_BUILD_ROOT
rm -f perlfiles.list
rm -rf howto


%files
%defattr(-,root,root)
%attr(755,root,root) %dir /usr/lib/pgsql
%attr(755,root,root) /usr/lib/libpq.so*
%attr(755,root,root) /usr/lib/libecpg.so*
%attr(755,root,root) /usr/lib/libpq++.so*
/usr/bin/createdb
/usr/bin/createlang
/usr/bin/createuser
/usr/bin/destroydb
/usr/bin/destroylang
/usr/bin/destroyuser
/usr/bin/pg_dump
/usr/bin/pg_dumpall
/usr/bin/pg_id
/usr/bin/psql
/usr/bin/vacuumdb

%files doc
%defattr(-,root,root)
%doc doc/FAQ doc/FAQ_Linux doc/README* 
%doc COPYRIGHT README HISTORY doc/bug.template
%doc contrib doc/unpacked/* 
%doc doc/*.ps.gz
/usr/man/man?/*.?

%files server
%defattr(-,root,root)
%attr(700,postgres,postgres) %{pgdata}
%attr(755,root,root) /usr/lib/plpgsql.so*
%attr(755,root,root) /usr/lib/pltcl.so*
/usr/bin/pg_encoding
/usr/bin/initdb
/usr/bin/initlocation
/usr/bin/pg_passwd
/usr/bin/pg_version
/usr/bin/postgres
/usr/bin/postmaster
/usr/lib/pgsql/*

%files devel
%defattr(-,root,root)
/usr/lib/libecpg.a
/usr/lib/libpq++.a
/usr/lib/libpq.a
/usr/bin/ecpg
/usr/include/pgsql

%files tcl
%defattr(-,root,root)
%attr(755,root,root) /usr/lib/libpgtcl.so*
%attr(755,root,root) /usr/lib/libpgtcl.a
%attr(555,root,root) /usr/bin/pgtclsh
%attr(555,root,root) /usr/bin/pgtksh

%files pgaccess
%defattr(-,root,root)
%attr(555,root,root) /usr/bin/pgaccess
%dir /usr/pgaccess
%attr(555,root,root) /usr/pgaccess/main.tcl
%dir /usr/pgaccess/lib
%attr(444,root,root) /usr/pgaccess/lib/*.tcl
%dir /usr/pgaccess/lib/help
%attr(444,root,root) /usr/pgaccess/lib/help/*.hlp
%dir /usr/pgaccess/lib/languages
%attr(444,root,root) /usr/pgaccess/lib/languages/*
%dir /usr/pgaccess/images
%attr(444,root,root) /usr/pgaccess/images/*.gif

%files odbc
%defattr(-,root,root)
%attr(755,root,root) /usr/lib/libpsqlodbc.so*
%attr(755,root,root) /usr/lib/libpsqlodbc.a
%attr(600,postgres,postgres) %{pgdata}/odbcinst.ini

%files -f perlfiles.list perl

%files python
%defattr(-,root,root)
/usr/lib/python1.5/site-packages/_pgmodule.so
/usr/lib/python1.5/site-packages/*.py

%files jdbc
%defattr(-,root,root)
/usr/lib/pgsql/jdbc%{pg_jdbc_version}.jar

